@@ -75,16 +75,14 @@ enum DisplayFormat { DBG_DF_NATURAL = 0, DBG_DF_HEXADECIMAL, DBG_DF_BINARY, DBG_
 //-------------------------------------------------------
 // Data structures used by the debugger
 //-------------------------------------------------------
-struct DebuggerInfo
-{
+struct DebuggerInfo {
     wxString name;
     wxString initFuncName;
     wxString version;
     wxString author;
 };
 
-struct StackEntry
-{
+struct StackEntry {
     wxString level;
     wxString address;
     wxString function;
@@ -93,8 +91,7 @@ struct StackEntry
     bool active;
 };
 
-struct ThreadEntry
-{
+struct ThreadEntry {
     bool active;
     long dbgid;
     wxString file;
@@ -102,8 +99,7 @@ struct ThreadEntry
     wxString function;
 };
 
-struct VariableObjChild
-{
+struct VariableObjChild {
     int numChilds;    // If this child has children (i.e. is this child a node or leaf)
     wxString varName; // the name of the variable object node
     wxString gdbId;   // A unique name given by gdb which holds this node information for further queries
@@ -117,8 +113,7 @@ struct VariableObjChild
     }
 };
 
-struct VariableObject
-{
+struct VariableObject {
     bool isPtr;        // if this variable object is of type pointer
     bool isPtrPtr;     // if this variable object is of type pointer pointer
     wxString gdbId;    // GDB unique identifier for this variable object
@@ -134,8 +129,7 @@ struct VariableObject
     }
 };
 
-struct LocalVariable
-{
+struct LocalVariable {
     wxString name;
     wxString value;
     wxString type;
@@ -149,14 +143,12 @@ struct LocalVariable
     ~LocalVariable() {}
 };
 
-struct VariableObjectUpdateInfo
-{
+struct VariableObjectUpdateInfo {
     wxArrayString removeIds;
     wxArrayString refreshIds;
 };
 
-struct DisassembleEntry
-{
+struct DisassembleEntry {
 public:
     wxString m_address;
     wxString m_function;
@@ -164,8 +156,7 @@ public:
     wxString m_inst;
 };
 
-struct DbgRegister
-{
+struct DbgRegister {
     wxString reg_name;
     wxString reg_value;
 };
@@ -307,12 +298,11 @@ public:
     bool operator==(const BreakpointInfo& BI)
     {
         return ((origin == BI.origin) && (what == BI.what) && (at == BI.at) && (file == BI.file) &&
-                (lineno == BI.lineno) && (function_name == BI.function_name) && (memory_address == BI.memory_address) &&
-                (bp_type == BI.bp_type) && (watchpt_data == BI.watchpt_data) && (is_enabled == BI.is_enabled) &&
-                (ignore_number == BI.ignore_number) && (conditions == BI.conditions) &&
-                (commandlist == BI.commandlist) && (is_temp == BI.is_temp) &&
-                (bp_type == BP_type_watchpt ? (watchpoint_type == BI.watchpoint_type) : true) &&
-                (!function_name.IsEmpty() ? (regex == BI.regex) : true));
+            (lineno == BI.lineno) && (function_name == BI.function_name) && (memory_address == BI.memory_address) &&
+            (bp_type == BI.bp_type) && (watchpt_data == BI.watchpt_data) && (is_enabled == BI.is_enabled) &&
+            (ignore_number == BI.ignore_number) && (conditions == BI.conditions) && (commandlist == BI.commandlist) &&
+            (is_temp == BI.is_temp) && (bp_type == BP_type_watchpt ? (watchpoint_type == BI.watchpoint_type) : true) &&
+            (!function_name.IsEmpty() ? (regex == BI.regex) : true));
     }
 
     bool IsNull() const { return internal_id == wxNOT_FOUND && debugger_id == wxNOT_FOUND; }
@@ -424,6 +414,9 @@ public:
 class DebuggerInformation : public SerializedObject
 {
 public:
+    enum eGdbFlags {
+        kPrintObjectOff = (1 << 0),
+    };
     wxString name;
     wxString path;
     bool enableDebugLog;
@@ -445,6 +438,7 @@ public:
     wxString cygwinPathCommand;
     bool charArrAsPtr;
     bool enableGDBPrettyPrinting;
+    size_t flags; // see eGdbFlags
 
 public:
     DebuggerInformation()
@@ -467,7 +461,8 @@ public:
         , applyBreakpointsAfterProgramStarted(false)
         , whenBreakpointHitRaiseCodelite(true)
         , charArrAsPtr(false)
-        , enableGDBPrettyPrinting(false)
+        , enableGDBPrettyPrinting(true)
+        , flags(0)
     {
     }
 
@@ -496,6 +491,7 @@ public:
         arch.Write(wxT("cygwinPathCommand"), cygwinPathCommand);
         arch.Write(wxT("charArrAsPtr"), charArrAsPtr);
         arch.Write(wxT("enableGDBPrettyPrinting"), enableGDBPrettyPrinting);
+        arch.Write("flags", flags);
     }
 
     void DeSerialize(Archive& arch)
@@ -527,6 +523,7 @@ public:
         arch.Read(wxT("cygwinPathCommand"), cygwinPathCommand);
         arch.Read(wxT("charArrAsPtr"), charArrAsPtr);
         arch.Read(wxT("enableGDBPrettyPrinting"), enableGDBPrettyPrinting);
+        arch.Read("flags", flags);
     }
 };
 
