@@ -195,10 +195,10 @@ void ContextBase::OnUserTypedXChars(const wxString& word)
     if(IsCommentOrString(GetCtrl().GetCurrentPos())) {
         return;
     }
-    
+
     const TagsOptionsData& options = TagsManagerST::Get()->GetCtagsOptions();
     if(options.GetFlags() & CC_WORD_ASSIST) {
-        // Try to call code completion 
+        // Try to call code completion
         clCodeCompletionEvent ccEvt(wxEVT_CC_CODE_COMPLETE);
         ccEvt.SetEditor(&GetCtrl());
         ccEvt.SetPosition(GetCtrl().GetCurrentPos());
@@ -288,6 +288,9 @@ void ContextBase::AutoAddComment()
                             where += match.length();
                             int caretPos = startPos + where;
                             rCtrl.SetCaretAt(caretPos);
+
+                            // Remove the @brief as its non standard in the PHP world
+                            rCtrl.DeleteRange(caretPos - match.length(), match.length());
                         }
                     }
                     rCtrl.EndUndoAction();
@@ -321,3 +324,47 @@ bool ContextBase::IsStringTriggerCodeComplete(const wxString& str) const
         return (m_completionTriggerStrings.count(str) > 0);
     }
 }
+
+int ContextBase::FindNext(const wxString& what, int& pos, bool wholePage)
+{
+    wxStyledTextCtrl* ctrl = GetCtrl().GetCtrl();
+    int startpos(wxNOT_FOUND);
+    int lastLine(wxNOT_FOUND);
+    int endpos(wxNOT_FOUND);
+    if(wholePage) {
+        startpos = ctrl->GetCurrentPos();
+        endpos = ctrl->GetLastPosition();
+    } else {
+        startpos = ctrl->PositionFromLine(ctrl->GetFirstVisibleLine());
+        lastLine = ctrl->GetFirstVisibleLine() + ctrl->LinesOnScreen();
+        endpos = ctrl->GetLineEndPosition(lastLine);
+    }
+    if((pos < startpos) || (pos > endpos)) return wxNOT_FOUND;
+    int where = ctrl->FindText(pos, endpos, what);
+    if(where != wxNOT_FOUND) {
+        pos = where + what.length();
+    }
+    return where;
+}
+
+int ContextBase::FindPrev(const wxString& what, int& pos, bool wholePage)
+{
+    wxStyledTextCtrl* ctrl = GetCtrl().GetCtrl();
+    int startpos(wxNOT_FOUND);
+    int lastLine(wxNOT_FOUND);
+    int endpos(wxNOT_FOUND);
+    if(wholePage) {
+        startpos = 0;
+        endpos = ctrl->GetCurrentPos();
+    } else {
+        startpos = ctrl->PositionFromLine(ctrl->GetFirstVisibleLine());
+        lastLine = ctrl->GetFirstVisibleLine() + ctrl->LinesOnScreen();
+        endpos = ctrl->GetLineEndPosition(lastLine);
+    }
+    if((pos < startpos) || (pos > endpos)) return wxNOT_FOUND;
+    int where = ctrl->FindText(pos, startpos, what);
+    if(where != wxNOT_FOUND) {
+        pos = where;
+    }
+    return where;
+}
